@@ -1,7 +1,8 @@
 /*
  * bmon/graph.h            Graph creation utility
  *
- * Copyright (c) 2001-2004 Thomas Graf <tgraf@suug.ch>
+ * Copyright (c) 2001-2013 Thomas Graf <tgraf@suug.ch>
+ * Copyright (c) 2013 Red Hat, Inc.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -26,32 +27,42 @@
 #define __BMON_GRAPH_H_
 
 #include <bmon/bmon.h>
-#include <bmon/item.h>
+#include <bmon/unit.h>
 
-#define D_ROW_SIZE (HISTORY_SIZE + 1)
-#define D_AT_ROW(P,R) ((P) + ((R) * D_ROW_SIZE))
-#define D_AT_COL(P, R) ((P) + (R))
+struct history;
 
-typedef struct table_s {
-	int               t_index;
-	int               t_height;
-	char *            t_data;
-	char *            t_x_unit;
-	char *            t_y_unit;
-	double *          t_y_scale;
-} table_t;
+struct graph_cfg {
+	int			gc_height,
+				gc_width,
+				gc_flags;
 
-#define GRAPH_HAS_FREEABLE_X_UNIT 1
-
-typedef struct graph_s {
-	int               g_flags;
-	table_t           g_rx;
-	table_t           g_tx;
-} graph_t;
+	char			gc_background,
+				gc_foreground,
+				gc_noise,
+				gc_unknown;
 	
-extern void free_graph(graph_t *);
-extern graph_t * create_graph(hist_elem_t *, int, int);
-extern graph_t * create_configued_graph(history_t *, int, int, int);
+	struct unit *		gc_unit;
+};
+
+struct graph_table {
+	char *			gt_table;
+	char *			gt_y_unit;
+	float *			gt_scale;
+};
+
+struct graph {
+	struct graph_cfg	g_cfg;
+	struct graph_table	g_rx,
+				g_tx;
+
+	struct list_head	g_list;
+};
+	
+extern void			graph_free(struct graph *);
+extern struct graph *		graph_alloc(struct history *, struct graph_cfg *);
+extern void			graph_refill(struct graph *, struct history *);
+
+extern size_t			graph_row_size(struct graph_cfg *);
 
 extern void new_graph(void);
 extern void del_graph(void);
