@@ -37,6 +37,8 @@ static int c_notc = 0;
 static struct element_group *grp;
 static struct bmon_module netlink_ops;
 
+#include <linux/if.h>
+
 #include <netlink/netlink.h>
 #include <netlink/cache.h>
 #include <netlink/utils.h>
@@ -736,7 +738,7 @@ static void do_link(struct nl_object *obj, void *arg)
 		attr_update(e, m->attrid, c_rx, c_tx, flags);
 	}
 
-	if (!c_notc)
+	if (!c_notc && qdisc_cache)
 		handle_tc(e, link);
 
 	element_notify_update(e, NULL);
@@ -752,7 +754,8 @@ static void netlink_read(void)
 		goto disable;
 	}
 
-	if ((err = nl_cache_resync(sock, qdisc_cache, NULL, NULL)) < 0) {
+	if (qdisc_cache &&
+	    (err = nl_cache_resync(sock, qdisc_cache, NULL, NULL)) < 0) {
 		fprintf(stderr, "Unable to resync qdisc cache: %s\n", nl_geterror(err));
 		goto disable;
 	}
@@ -772,6 +775,17 @@ static void netlink_shutdown(void)
 	nl_socket_free(sock);
 }
 
+static void netlink_use_bit(struct attr_map *map, const int size)
+{
+	if(cfg_getbool(cfg, "use_bit")) {
+		for(int i = 0; i < size; ++i) {
+			if(!strcmp(map[i].description, "Bytes")) {
+				map[i].description = "Bits";
+			}
+		}
+	}
+}
+
 static int netlink_do_init(void)
 {
 	int err;
@@ -792,10 +806,13 @@ static int netlink_do_init(void)
 	}
 
 	if ((err = rtnl_qdisc_alloc_cache(sock, &qdisc_cache)) < 0) {
-		fprintf(stderr, "Unable to allocate qdisc cache: %s\n", nl_geterror(err));
-		goto disable;
+		fprintf(stderr, "Warning: Unable to allocate qdisc cache: %s\n", nl_geterror(err));
+		fprintf(stderr, "Disabling QoS statistics.\n");
+		qdisc_cache = NULL;
 	}
 
+	netlink_use_bit(link_attrs, ARRAY_SIZE(link_attrs));
+	netlink_use_bit(tc_attrs, ARRAY_SIZE(tc_attrs));
 	if (attr_map_load(link_attrs, ARRAY_SIZE(link_attrs)) ||
 	    attr_map_load(tc_attrs, ARRAY_SIZE(tc_attrs)))
 		BUG();
@@ -817,17 +834,17 @@ static int netlink_probe(void)
 
 	if (!(sock = nl_socket_alloc()))
 		return 0;
-	
+
 	if (nl_connect(sock, NETLINK_ROUTE) < 0)
 		return 0;
-	
+
 	if (rtnl_link_alloc_cache(sock, AF_UNSPEC, &lc) == 0) {
 		nl_cache_free(lc);
 		ret = 1;
 	}
 
 	nl_socket_free(sock);
-	
+
 	return ret;
 }
 
