@@ -148,7 +148,7 @@ static void put_line(const char *fmt, ...)
 {
 	va_list args;
 	char buf[2048];
-	int x, y;
+	int x, y __unused__;
 
 	memset(buf, 0, sizeof(buf));
 	getyx(stdscr, y, x);
@@ -172,7 +172,10 @@ static void center_text(const char *fmt, ...)
 	unsigned int col;
 
 	va_start(args, fmt);
-	vasprintf(&str, fmt, args);
+	if (vasprintf(&str, fmt, args) < 0) {
+		fprintf(stderr, "vasprintf: Out of memory\n");
+		exit(ENOMEM);
+	}
 	va_end(args);
 
 	col = (cols / 2) - (strlen(str) / 2);
@@ -1112,7 +1115,7 @@ static int handle_input(int ch)
 
 		case '?':
 			clear();
-			print_help = 1;
+			print_help = print_help ? 0 : 1;
 			return 1;
 
 		case KEY_TOGGLE_GRAPH:
@@ -1202,6 +1205,13 @@ static int handle_input(int ch)
 
 static void curses_pre(void)
 {
+	static int init = 0;
+
+	if (!init) {
+		curses_init();
+		init = 1;
+	}
+
 	for (;;) {
 		int ch = getch();
 
@@ -1249,7 +1259,7 @@ static void curses_parse_opt(const char *type, const char *value)
 		c_graph_cfg.gc_height = strtol(value, NULL, 0);
 	else if (!strcasecmp(type, "gwidth") && value)
 		c_graph_cfg.gc_width = strtol(value, NULL, 0);
-	else if (!strcasecmp(type, "ngraph")) {
+	else if (!strcasecmp(type, "ngraph") && value) {
 		c_ngraph = strtol(value, NULL, 0);
 		c_show_graph = !!c_ngraph;
 	} else if (!strcasecmp(type, "details"))
@@ -1267,7 +1277,6 @@ static void curses_parse_opt(const char *type, const char *value)
 static struct bmon_module curses_ops = {
 	.m_name		= "curses",
 	.m_flags	= BMON_MODULE_DEFAULT,
-	.m_init		= curses_init,
 	.m_shutdown	= curses_shutdown,
 	.m_pre		= curses_pre,
 	.m_do		= curses_draw,
